/**
 * A bare bones plain text editor with syntax highlighting.
 * @customElement
 * @tagname light-editor
 *
 * @event {Event} light-change - Re-emits the textarea's "change" event
 * @event {Event} light-selectionchange - Re-emits the textarea's "selectionchange" event
 * @event {Event} light-input - Re-emits the textarea's "input" event
 *
 */
export default class LightEditor extends BaseElement {
    static styles: import("lit").CSSResult[];
    static properties: {
        label: {};
        value: {};
        language: {
            reflect: boolean;
        };
    };
    /**
     * @type {string}
     */
    language: string;
    /**
     * @type {string}
     */
    value: string;
    /**
     * @type {null | HTMLTextAreaElement}
     */
    textarea: null | HTMLTextAreaElement;
    /**
     * @ignore
     * @param {ResizeObserverEntry[]} entries
     */
    handleTextAreaResize(entries: ResizeObserverEntry[]): void;
    render(): import("lit").TemplateResult<1>;
    /**
     * @ignore
     * @param {Element | undefined} element
     */
    textareaChanged(element: Element | undefined): void;
    textareaResizeObserver: ResizeObserver | undefined;
    textareaMutationObserver: MutationObserver | undefined;
    /**
     * @ignore
     * @param {Event} e
     */
    handleSlotChangeEvent(e: Event): void;
    /**
     * @internal
     * @param {Event} e
     */
    syncScroll(e: Event): void;
    /**
     * @ignore
     * @param {KeyboardEvent} evt
     */
    keydownHandler(evt: KeyboardEvent): void;
    /**
     * @ignore
     * Override this to use a highlighter of your choice.
     * @param {{code: string, language: string}} options
     */
    highlightCode(options: {
        code: string;
        language: string;
    }): string;
    /**
     * @ignore
     * @param {string} text
     */
    unescapeCharacters(text: string): string;
    /**
     * @ignore
     * Highlighters strip newlines. But you can see new lines in <textarea>, this fixes that.
     * @param {string} text
     */
    injectNewLine(text: string): string;
}
import { BaseElement } from "../internal/base-element.js";
